Module: Google::Apis::AndroiddeveloperidstatusV1

Defined in:
lib/google/apis/androiddeveloperidstatus_v1.rb,
lib/google/apis/androiddeveloperidstatus_v1/classes.rb,
lib/google/apis/androiddeveloperidstatus_v1/service.rb,
lib/google/apis/androiddeveloperidstatus_v1/gem_version.rb,
lib/google/apis/androiddeveloperidstatus_v1/representations.rb

Overview

Android Developer ID Status API

Android Developer ID Status API.

Defined Under Namespace

Classes: AndroidDeveloperIDStatusService, PackageRegistrationStatus

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-androiddeveloperidstatus_v1 gem

"0.1.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.19.0"
REVISION =

Revision of the discovery document this client was generated from

"20260804"
VERSION =

Version of the Android Developer ID Status API this client connects to. This is NOT the gem version.

'V1'