Class: Google::Apis::AndroiddeveloperidstatusV1::AndroidDeveloperIDStatusService

Inherits:
Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/androiddeveloperidstatus_v1/service.rb

Overview

Android Developer ID Status API

Android Developer ID Status API.

Examples:

require 'google/apis/androiddeveloperidstatus_v1'

Androiddeveloperidstatus = Google::Apis::AndroiddeveloperidstatusV1 # Alias the module
service = Androiddeveloperidstatus::AndroidDeveloperIDStatusService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://androiddeveloperidstatus.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeAndroidDeveloperIDStatusService

Returns a new instance of AndroidDeveloperIDStatusService.



47
48
49
50
51
52
# File 'lib/google/apis/androiddeveloperidstatus_v1/service.rb', line 47

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-androiddeveloperidstatus_v1',
        client_version: Google::Apis::AndroiddeveloperidstatusV1::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



40
41
42
# File 'lib/google/apis/androiddeveloperidstatus_v1/service.rb', line 40

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



45
46
47
# File 'lib/google/apis/androiddeveloperidstatus_v1/service.rb', line 45

def quota_user
  @quota_user
end

Instance Method Details

#check_package_package_registration_status(name, certificate_fingerprint: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroiddeveloperidstatusV1::PackageRegistrationStatus

Retrieves the Android Developer ID registration status for a given package.

Parameters:

  • name (String)

    Required. The name of the package registration status resource. Format: packages/package/packageRegistrationStatus package must follow the specific format: The fully-qualified Android package name with dots ('.') replaced by hyphens ('-') (e.g., com-example-app instead of com.example.app ).

  • certificate_fingerprint (String) (defaults to: nil)

    Optional. The SHA-256 fingerprint of the public certificate represented as a 64-character lowercase hexadecimal string without any colons or separators (e. g., d6ac89ed1d0a805aad4b087d06d5f41645b814480b133fbc867ef7498d069e06).

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



82
83
84
85
86
87
88
89
90
91
# File 'lib/google/apis/androiddeveloperidstatus_v1/service.rb', line 82

def check_package_package_registration_status(name, certificate_fingerprint: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}:check', options)
  command.response_representation = Google::Apis::AndroiddeveloperidstatusV1::PackageRegistrationStatus::Representation
  command.response_class = Google::Apis::AndroiddeveloperidstatusV1::PackageRegistrationStatus
  command.params['name'] = name unless name.nil?
  command.query['certificateFingerprint'] = certificate_fingerprint unless certificate_fingerprint.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end