Class: Google::Apis::AndroiddeveloperidstatusV1::PackageRegistrationStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androiddeveloperidstatus_v1/classes.rb,
lib/google/apis/androiddeveloperidstatus_v1/representations.rb,
lib/google/apis/androiddeveloperidstatus_v1/representations.rb

Overview

Resource message PackageRegistrationStatus.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageRegistrationStatus

Returns a new instance of PackageRegistrationStatus.



50
51
52
# File 'lib/google/apis/androiddeveloperidstatus_v1/classes.rb', line 50

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_fingerprintString

Output only. The SHA-256 fingerprint of the public certificate represented as a 64-character lowercase hexadecimal string without any colons or separators ( e.g., d6ac89ed1d0a805aad4b087d06d5f41645b814480b133fbc867ef7498d069e06). Corresponds to the JSON property certificateFingerprint

Returns:

  • (String)


34
35
36
# File 'lib/google/apis/androiddeveloperidstatus_v1/classes.rb', line 34

def certificate_fingerprint
  @certificate_fingerprint
end

#nameString

Identifier. The name of the package registration status resource. Format: packages/package/packageRegistrationStatus package must follow the specific format: The fully-qualified Android package name with dots ('.') replaced by hyphens ('-') (e.g., com-example-app instead of com.example.app ). Corresponds to the JSON property name

Returns:

  • (String)


43
44
45
# File 'lib/google/apis/androiddeveloperidstatus_v1/classes.rb', line 43

def name
  @name
end

#stateString

Output only. Registration state of the package, or pair. Corresponds to the JSON property state

Returns:

  • (String)


48
49
50
# File 'lib/google/apis/androiddeveloperidstatus_v1/classes.rb', line 48

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55
56
57
58
59
# File 'lib/google/apis/androiddeveloperidstatus_v1/classes.rb', line 55

def update!(**args)
  @certificate_fingerprint = args[:certificate_fingerprint] if args.key?(:certificate_fingerprint)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end